import type { AnonCredsRegistry, GetCredentialDefinitionReturn, GetSchemaReturn, RegisterSchemaReturn, RegisterCredentialDefinitionReturn, GetRevocationStatusListReturn, GetRevocationRegistryDefinitionReturn, AnonCredsSchema, AnonCredsCredentialDefinition, RegisterSchemaReturnStateFailed, RegisterSchemaReturnStateFinished, RegisterSchemaReturnStateAction, RegisterSchemaReturnStateWait, RegisterCredentialDefinitionReturnStateAction, RegisterCredentialDefinitionReturnStateWait, RegisterCredentialDefinitionReturnStateFinished, RegisterCredentialDefinitionReturnStateFailed } from '@aries-framework/anoncreds';
import type { AgentContext } from '@aries-framework/core';
export declare class IndyVdrAnonCredsRegistry implements AnonCredsRegistry {
    readonly methodName = "indy";
    readonly supportedIdentifier: RegExp;
    getSchema(agentContext: AgentContext, schemaId: string): Promise<GetSchemaReturn>;
    registerSchema(agentContext: AgentContext, options: IndyVdrRegisterSchema): Promise<IndyVdrRegisterSchemaReturn>;
    getCredentialDefinition(agentContext: AgentContext, credentialDefinitionId: string): Promise<GetCredentialDefinitionReturn>;
    registerCredentialDefinition(agentContext: AgentContext, options: IndyVdrRegisterCredentialDefinition): Promise<IndyVdrRegisterCredentialDefinitionReturn>;
    getRevocationRegistryDefinition(agentContext: AgentContext, revocationRegistryDefinitionId: string): Promise<GetRevocationRegistryDefinitionReturn>;
    getRevocationStatusList(agentContext: AgentContext, revocationRegistryId: string, timestamp: number): Promise<GetRevocationStatusListReturn>;
    private fetchIndySchemaWithSeqNo;
}
type InternalEndorsement = {
    endorserMode: 'internal';
    endorserDid: string;
    endorsedTransaction?: never;
};
type ExternalEndorsementCreate = {
    endorserMode: 'external';
    endorserDid: string;
    endorsedTransaction?: never;
};
type ExternalEndorsementSubmit = {
    endorserMode: 'external';
    endorserDid?: never;
    endorsedTransaction: string;
};
export interface IndyVdrRegisterSchemaInternalOptions {
    schema: AnonCredsSchema;
    options: InternalEndorsement;
}
export interface IndyVdrRegisterSchemaExternalCreateOptions {
    schema: AnonCredsSchema;
    options: ExternalEndorsementCreate;
}
export interface IndyVdrRegisterSchemaExternalSubmitOptions {
    schema: AnonCredsSchema;
    options: ExternalEndorsementSubmit;
}
export interface IndyVdrRegisterSchemaReturnStateAction extends RegisterSchemaReturnStateAction {
    action: 'endorseIndyTransaction';
    schemaRequest: string;
}
export interface IndyVdrRegisterSchemaReturn extends RegisterSchemaReturn {
    schemaState: RegisterSchemaReturnStateWait | IndyVdrRegisterSchemaReturnStateAction | RegisterSchemaReturnStateFinished | RegisterSchemaReturnStateFailed;
}
export type IndyVdrRegisterSchema = IndyVdrRegisterSchemaInternalOptions | IndyVdrRegisterSchemaExternalCreateOptions | IndyVdrRegisterSchemaExternalSubmitOptions;
export type IndyVdrRegisterSchemaOptions = IndyVdrRegisterSchema['options'];
export interface IndyVdrRegisterCredentialDefinitionInternalOptions {
    credentialDefinition: AnonCredsCredentialDefinition;
    options: InternalEndorsement;
}
export interface IndyVdrRegisterCredentialDefinitionExternalCreateOptions {
    credentialDefinition: AnonCredsCredentialDefinition;
    options: ExternalEndorsementCreate;
}
export interface IndyVdrRegisterCredentialDefinitionExternalSubmitOptions {
    credentialDefinition: AnonCredsCredentialDefinition;
    options: ExternalEndorsementSubmit;
}
export interface IndyVdrRegisterCredentialDefinitionReturnStateAction extends RegisterCredentialDefinitionReturnStateAction {
    action: 'endorseIndyTransaction';
    credentialDefinitionRequest: string;
}
export interface IndyVdrRegisterCredentialDefinitionReturn extends RegisterCredentialDefinitionReturn {
    credentialDefinitionState: RegisterCredentialDefinitionReturnStateWait | IndyVdrRegisterCredentialDefinitionReturnStateAction | RegisterCredentialDefinitionReturnStateFinished | RegisterCredentialDefinitionReturnStateFailed;
}
export type IndyVdrRegisterCredentialDefinition = IndyVdrRegisterCredentialDefinitionInternalOptions | IndyVdrRegisterCredentialDefinitionExternalCreateOptions | IndyVdrRegisterCredentialDefinitionExternalSubmitOptions;
export type IndyVdrRegisterCredentialDefinitionOptions = IndyVdrRegisterCredentialDefinition['options'];
export {};
